function [ partial ] = partial_derivative_of_position( )

%% obtain the error_ellipse package from mathworks 3rd party site
addpath error_ellipse
% m is mic matrix

% parallel close pairs
% m = [ 3.4 3.6 4.4 4.6 ; 0.2 0.2 0.2 0.2];

% parallel distant pairs
% m = [ 2.4 2.6 5.4 5.6 ; 0.2 0.2 0.2 0.2];

% orthogonal pairs
m = [ 3.9 4.1 0.2 0.2 ; 0.2 0.2 2.4 2.6];

M = size(m,2);
dim = size(m,1);

% define which microphones are used as a single pair.
ind = [1 2 ; 3 4];

prs = length(ind);

% speed of sound divided with samplerate
c=343/48000;

% variance of TDOA in samples
var_=1;

% a grid of source coordinate points to evaluate
vx = linspace(2,6,5);
vy = linspace(1,6,5);

figure;plot(m(1,:),m(2,:),'bd','markerfacecolor','k','markersize',10);

for xi = 1:length(vx)
    for yi = 1:length(vy)

        p = [vx(xi);vy(yi)];
        
        pr = repmat(p,1,prs);

        % partial derivative of TDOA w.r.t. source position
        A = ( pr - m(:,ind(:,1)) );
        B = ( pr - m(:,ind(:,2)) );        
        A = A ./ repmat(sqrt(sum(A.^2,1)),dim,1);
        B = B ./ repmat(sqrt(sum(B.^2,1)),dim,1);
        J =  (A' - B')/c;
        
        hold on;grid on;plot(p(1),p(2),'ko','markerfacecolor','g');

        try
            pos_error_cov_mtx = inv(J'*J)*var_;
            error_ellipse( pos_error_cov_mtx, p,'conf',0.68268,'style','r' )
        catch
        end
    end
end

% legend('mic','source','1\sigma confidence')
axis([0 8 0 8])
xlabel('m');ylabel('m');

                
